Somebody's Food Diary | MyFitnessPal.com
Description: Free online calorie counter and diet plan. Lose weight by tracking your caloric intake quickly and easily. Find nutrition facts for over 2,000,000 foods.
Keywords: calorie counter, free diet journal, weight loss program, nutrition facts, online calorie counter, free diet plan, weight loss online, free calorie counter

Calorie Counter

# Your Food Diary For:

Prev Saturday July 13, 2013 Next

Breakfast | Calories | Carbs | Fat | Protein | Sodium | Sugar
Dave's Killer Bread - Blues Bread, 2 slice | 240 | 44 20 | 6 | 10 | 380 | 8 |
Earth Balance - Natural Buttery Spread - Original, 1 tbsp (14g) | 100 | 0 | 11 | 0 | 100 | 0 |
Add Food Quick Tools Quick add calories Remember meal Copy from date Copy to today Copy to date Copy from which date? Friday, July 12 Thursday, July 11 Wednesday, July 10 Tuesday, July 9 Monday, July 8 Sunday, July 7 Saturday, July 6 Copy from which date? Thursday, July 18 Wednesday, July 17 Tomorrow Today Yesterday Saturday, July 13 Friday, July 12 | 340 | 44 | 17 | 10 | 480 | 8 |
Lunch
Add Food Quick Tools Quick add calories Copy from date Copy to today Copy to date Copy from which date? Friday, July 12 Thursday, July 11 Wednesday, July 10 Tuesday, July 9 Monday, July 8 Sunday, July 7 Saturday, July 6 Copy from which date? Thursday, July 18 Wednesday, July 17 Tomorrow Today Yesterday Saturday, July 13 Friday, July 12 |  |  |  |  |  |  |
Dinner
Wine - Pinot Noir Wine, 12 oz | 288 | 8 | 0 | 0 | 5 | 0 |
Generic - Baked Macaroni and Cheese, 14 grams | 690 | 64 | 48 | 30 | 1,166 | 14 |
Add Food Quick Tools Quick add calories Remember meal Copy from date Copy to today Copy to date Copy from which date? Friday, July 12 Thursday, July 11 Wednesday, July 10 Tuesday, July 9 Monday, July 8 Sunday, July 7 Saturday, July 6 Copy from which date? Thursday, July 18 Wednesday, July 17 Tomorrow Today Yesterday Saturday, July 13 Friday, July 12 | 978 | 72 | 48 | 30 | 1,171 | 14 |
Snacks
Mrm - Dutch Chocolate Whey Protein, 2 scoop | 170 | 3 | 2 | 36 | 80 | 2 |
Drinks - Almond Milk (Vanilla), 18 oz | 203 | 36 | 6 | 2 | 338 | 34 |
Dogfish Head 90 Minute Ipa - Beer, India Pale Ale, 24 oz | 588 | 48 | 0 | 0 | 0 | 0 |
Add Food Quick Tools Quick add calories Remember meal Copy from date Copy to today Copy to date Copy from which date? Friday, July 12 Thursday, July 11 Wednesday, July 10 Tuesday, July 9 Monday, July 8 Sunday, July 7 Saturday, July 6 Copy from which date? Thursday, July 18 Wednesday, July 17 Tomorrow Today Yesterday Saturday, July 13 Friday, July 12 | 961 | 87 | 8 | 38 | 418 | 36 |
Totals | 2,279 | 203 | 73 | 78 | 2,069 | 58 |
Your Daily Goal | 2,500 | 343 | 84 | 93 | 2,500 | 50 |
Remaining | 221 | 140 | 11 | 15 | 431 | -8 |
| Calories | Carbs | Fat | Protein | Sodium | Sugar |

When you're finished logging all foods and exercise for this day, click here:
Complete This Entry

### Water Consumption

We recommend that you drink at least 8 cups of water a day. Click the arrows to add or subtract cups of water.

Up 0 Down

#### Today's Food Notes

Edit Note

Save Note

View Full Report (Printable)